@@ -21,8 +21,6 @@
 
 #include "config.h"
 
-#include <gnome.h>
-
 #ifdef WITH_SHARING 
 #include <avahi-client/client.h>
 #include <avahi-client/lookup.h>
@@ -32,7 +30,10 @@
 #include "seahorse-util.h"
 #include "seahorse-dns-sd.h"
 #include "seahorse-context.h"
-#include "seahorse-server-source.h"
+
+#ifdef WITH_PGP
+#include "pgp/seahorse-server-source.h"
+#endif
 
 /* Override the DEBUG_DNSSD_ENABLE switch here */
 /* #define DEBUG_DNSSD_ENABLE 1 */
@@ -63,6 +64,8 @@ struct _SeahorseServiceDiscoveryPriv {
 #ifdef WITH_SHARING
     AvahiClient *client;
     AvahiServiceBrowser *browser;
+#else
+    char no_use;
 #endif
 };
 
@@ -118,7 +121,8 @@ resolve_callback (AvahiServiceResolver *resolver, AvahiIfIndex iface, AvahiProto
     case AVAHI_RESOLVER_FOUND:
         
         /* Make sure it's our type ... */
-        if (g_strcasecmp (HKP_SERVICE_TYPE, type) != 0)
+        /* XXX Is the service always guaranteed to be ascii? */
+        if (g_ascii_strcasecmp (HKP_SERVICE_TYPE, type) != 0)
             break;
         
 #ifndef DISCOVER_THIS_HOST
@@ -137,10 +141,10 @@ resolve_callback (AvahiServiceResolver *resolver, AvahiIfIndex iface, AvahiProto
         g_signal_emit (ssd, signals[ADDED], 0, service_name);
     
         /* Add it to the context */
-        if (!seahorse_context_remote_key_source (SCTX_APP (), service_uri)) {
+        if (!seahorse_context_remote_source (SCTX_APP (), service_uri)) {
             SeahorseServerSource *ssrc = seahorse_server_source_new (service_uri);
             g_return_if_fail (ssrc != NULL);
-            seahorse_context_add_key_source (SCTX_APP (), SEAHORSE_KEY_SOURCE (ssrc));
+            seahorse_context_add_source (SCTX_APP (), SEAHORSE_SOURCE (ssrc));
         }
     
         DEBUG_DNSSD (("DNS-SD added: %s %s\n", service_name, service_uri));
@@ -165,7 +169,8 @@ browse_callback(AvahiServiceBrowser *browser, AvahiIfIndex iface, AvahiProtocol
     g_assert (SEAHORSE_IS_SERVICE_DISCOVERY (ssd));
     g_assert (browser == ssd->priv->browser);
     
-    if (g_strcasecmp (HKP_SERVICE_TYPE, type) != 0)
+     /* XXX Is the service always guaranteed to be ascii? */
+    if (g_ascii_strcasecmp (HKP_SERVICE_TYPE, type) != 0)
         return;
 
     switch (event) {
@@ -188,8 +193,8 @@ browse_callback(AvahiServiceBrowser *browser, AvahiIfIndex iface, AvahiProtocol
         uri = g_hash_table_lookup (ssd->services, name);
         if (uri != NULL) {
             /* Remove it from the main context */
-            SeahorseKeySource *sksrc = seahorse_context_remote_key_source (SCTX_APP(), uri);
-            seahorse_context_remove_key_source (SCTX_APP(), sksrc);
+            SeahorseSource *sksrc = seahorse_context_remote_source (SCTX_APP(), uri);
+            seahorse_context_remove_source (SCTX_APP(), sksrc);
         }
         
         /* And remove it from our tables */
@@ -237,28 +242,28 @@ service_key_list (const gchar* key, const gchar* value, GSList **arg)
 static void
 seahorse_service_discovery_init (SeahorseServiceDiscovery *ssd)
 {
-    int aerr;
-    
     ssd->priv = g_new0 (SeahorseServiceDiscoveryPriv, 1);
     ssd->services = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
     
 #ifdef WITH_SHARING
-    ssd->priv->client = avahi_client_new (seahorse_util_dns_sd_get_poll (), 
-                                          0, client_callback, ssd, &aerr);
-    if (!ssd->priv->client) {
-        g_message ("DNS-SD initialization failed: %s", avahi_strerror (aerr));
-        return;
-    }
-    
-    ssd->priv->browser = avahi_service_browser_new (ssd->priv->client, AVAHI_IF_UNSPEC, 
-                                AVAHI_PROTO_UNSPEC, HKP_SERVICE_TYPE, NULL, 0, 
-                                browse_callback, ssd);
-    if (!ssd->priv->browser) {
-        g_warning ("Browsing for DNS-SD services failed: %s", 
-                   avahi_strerror (avahi_client_errno (ssd->priv->client)));
-        return;
-    }
+	{
+		int aerr;
+		ssd->priv->client = avahi_client_new (seahorse_util_dns_sd_get_poll (), 
+		                                      0, client_callback, ssd, &aerr);
+		if (!ssd->priv->client) {
+			g_warning ("DNS-SD initialization failed: %s", avahi_strerror (aerr));
+			return;
+		}
     
+		ssd->priv->browser = avahi_service_browser_new (ssd->priv->client, AVAHI_IF_UNSPEC, 
+		                                                AVAHI_PROTO_UNSPEC, HKP_SERVICE_TYPE, NULL, 0, 
+		                                                browse_callback, ssd);
+		if (!ssd->priv->browser) {
+			g_warning ("Browsing for DNS-SD services failed: %s", 
+			           avahi_strerror (avahi_client_errno (ssd->priv->client)));
+			return;
+		}
+	}
 #endif /* WITH_SHARING */
 }
 
@@ -279,10 +284,10 @@ seahorse_service_discovery_finalize (GObject *gobject)
 {
     SeahorseServiceDiscovery *ssd = SEAHORSE_SERVICE_DISCOVERY (gobject);
   
-#ifdef WITH_SHARING    
+#ifdef WITH_SHARING
     g_assert (ssd->priv->browser == NULL);
     g_assert (ssd->priv->client == NULL);
-#endif /* WITH_SHARING */    
+#endif     
 
     if (ssd->services)    
         g_hash_table_destroy (ssd->services);
